@@ -1,7 +1,11 @@
 from .base import ConfigParserBase
 from apacheconfig import make_loader
+from threading import BoundedSemaphore
 from typing import Dict
 
+max_concurrent_parsers = 1
+parser_semaphore = BoundedSemaphore(value=max_concurrent_parsers)
+
 
 class ApacheConfigParser(ConfigParserBase):
     __slots__ = ["content"]
@@ -19,10 +23,11 @@ class ApacheConfigParser(ConfigParserBase):
 
         # statsd configuration needs to be loaded before it can be used,
         # so we can't measure the loading easily
-        with make_loader() as loader:
+
+        global parser_semaphore
+        with make_loader() as loader, parser_semaphore:
             config = loader.loads(content)
 
         if "statsd" in config:
             self.statsd.get_counter().increment("parse")
-
         return config
