@@ -81,6 +81,19 @@ class Event:
         ]
         return values[0]
 
+    def new_value(self, key):
+        """ Returns the "new value" from the changelog for the given attribute
+
+        :return: value containing the old value
+        :rtype: str
+        """
+        values = [
+            change["new_value"]
+            for change in self.changes
+            if change["key"] == key
+        ]
+        return values[0]
+
 
 class EventService(Base):
     __slots__ = [
