@@ -30,6 +30,9 @@ class TestBase:
     database access
     """
 
+    _cmd_instance_args = None
+    session = None
+
     def load_query_instance(self, domain: object, inframocks: dict = {}):
         """ Loads your object with a qry attribute pointing to the query
         instance
@@ -73,14 +76,26 @@ class TestBase:
 
         """
 
-        mock_session = mock.MagicMock()
+        self._cmd_instance_args = {"domain": domain, "inframocks": inframocks}
+
+        if not self.session:
+            self.session = mock.MagicMock()
+
         self.cmd = self._get_mocked_domain_instance(
-            session_mock=mock_session,
+            session_mock=self.session,
             domain=domain,
             instance_type="command",
             inframocks=inframocks,
         )
-        self.session = mock_session
+
+    def get_cmd(self):
+        if not self._cmd_instance_args:
+            raise Exception(
+                "Please make sure you first load the command_instance"
+            )
+
+        self.load_command_instance(**self._cmd_instance_args)
+        return self.cmd
 
     def assert_has_event_name(self, event_name: str, description: str = None):
         list_of_events = [
