@@ -70,7 +70,12 @@ def _reflect(value):
     :return: converted object to correct type
     :rtype: str, int or None
     """
-    if (value is None) or isinstance(value, bool) or isinstance(value, int):
+    if (
+        (value is None)
+        or isinstance(value, bool)
+        or isinstance(value, int)
+        or isinstance(value, float)
+    ):
         return value
 
     if isinstance(value, EntityBase):
@@ -252,6 +257,8 @@ class Entity(IntrospectableObject):
                 entity_data={},
             )
 
+            return wrapped_entity
+
         return wrapper
 
 
